@@ -3,7 +3,7 @@
 #
 # Author: Slaven Rezic
 #
-# Copyright (C) 2010 Slaven Rezic. All rights reserved.
+# Copyright (C) 2010,2012 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -14,7 +14,7 @@
 package Acme::PM::Berlin::Meetings;
 
 use strict;
-our $VERSION = '201008.26';
+our $VERSION = '201212.19';
 
 use Exporter 'import'; # needs Exporter 5.57
 our @EXPORT = qw(next_meeting);
@@ -23,7 +23,7 @@ use DateTime;
 use DateTime::Event::Recurrence;
 
 our $NORMAL_RECURRENCE;
-our $XMAS_FALLBACK_RECURRENCE;
+our $ADVANCE_ONE_WEEK_RECURRENCE;
 
 sub next_meeting {
     my $count = shift || 1;
@@ -41,14 +41,14 @@ sub next_meeting_dt {
 	$der;
     };
     my $next_dt = $NORMAL_RECURRENCE->next($dt);
-    if (($next_dt->month == 12 && $next_dt->day >= 24) ||
-	($next_dt->month == 1  && $next_dt->day == 1)) {
-	$XMAS_FALLBACK_RECURRENCE ||= do {
-	    my $der = DateTime::Event::Recurrence->monthly(weeks =>  1, days => 'we', hours => 20, week_start_day => 'mo');
+    while(($next_dt->month == 12 && $next_dt->day >= 24) ||
+	  ($next_dt->month == 1  && $next_dt->day <= 2)) {
+	$ADVANCE_ONE_WEEK_RECURRENCE ||= do {
+	    my $der = DateTime::Event::Recurrence->weekly(days => 'we', hours => 20, week_start_day => 'mo');
 #	    $der->set_time_zone('Europe/Berlin');
 	    $der;
 	};
-	$next_dt = $XMAS_FALLBACK_RECURRENCE->next($next_dt);
+	$next_dt = $ADVANCE_ONE_WEEK_RECURRENCE->next($next_dt);
     }
     $next_dt;
 }   
@@ -66,6 +66,11 @@ Acme::PM::Berlin::Meetings - get the next date of the Berlin PM meeting
     use Acme::PM::Berlin::Meetings;
     next_meeting(1)
 
+=head1 NOTES
+
+This module knows about special Berlin.PM traditions like postponing
+the December meeting to the first or second week in January.
+
 =head1 AUTHOR
 
 Slaven Rezic
